@@ -3,6 +3,7 @@
 
 
 #include <glbinding/nogl.h>
+
 #include <glbinding/gl/values.h>
 
 
@@ -10,9 +11,12 @@ namespace gl15ext
 {
 
 
+// import values to namespace
+using gl::GL_ALL_PIXELS_AMD;
 using gl::GL_INVALID_INDEX;
-
+using gl::GL_LUID_SIZE_EXT;
 using gl::GL_TIMEOUT_IGNORED;
+using gl::GL_UUID_SIZE_EXT;
 
 
-} // namespace gl15ext
+} // namespace gl15ext
\ No newline at end of file
