@@ -9,10 +9,11 @@
 namespace gl41ext
 {
 
-
+// import functions
 using gl::glAccumxOES;
 using gl::glAcquireKeyedMutexWin32EXT;
 using gl::glActiveProgramEXT;
+using gl::glActiveShaderProgramEXT;
 using gl::glActiveStencilFaceEXT;
 using gl::glActiveTextureARB;
 using gl::glActiveVaryingNV;
@@ -27,6 +28,8 @@ using gl::glAreProgramsResidentNV;
 using gl::glAreTexturesResidentEXT;
 using gl::glArrayElementEXT;
 using gl::glArrayObjectATI;
+using gl::glAsyncCopyBufferSubDataNVX;
+using gl::glAsyncCopyImageSubDataNVX;
 using gl::glAsyncMarkerSGIX;
 using gl::glAttachObjectARB;
 using gl::glBeginConditionalRenderNV;
@@ -62,14 +65,15 @@ using gl::glBindMultiTextureEXT;
 using gl::glBindParameterEXT;
 using gl::glBindProgramARB;
 using gl::glBindProgramNV;
+using gl::glBindProgramPipelineEXT;
 using gl::glBindRenderbufferEXT;
 using gl::glBindSamplers;
 using gl::glBindShadingRateImageNV;
 using gl::glBindTexGenParameterEXT;
 using gl::glBindTextureEXT;
+using gl::glBindTextures;
 using gl::glBindTextureUnit;
 using gl::glBindTextureUnitParameterEXT;
-using gl::glBindTextures;
 using gl::glBindTransformFeedbackNV;
 using gl::glBindVertexArrayAPPLE;
 using gl::glBindVertexBuffer;
@@ -94,17 +98,17 @@ using gl::glBlendBarrierNV;
 using gl::glBlendColorEXT;
 using gl::glBlendColorxOES;
 using gl::glBlendEquationEXT;
+using gl::glBlendEquationiARB;
 using gl::glBlendEquationIndexedAMD;
 using gl::glBlendEquationSeparateEXT;
-using gl::glBlendEquationSeparateIndexedAMD;
 using gl::glBlendEquationSeparateiARB;
-using gl::glBlendEquationiARB;
+using gl::glBlendEquationSeparateIndexedAMD;
+using gl::glBlendFunciARB;
 using gl::glBlendFuncIndexedAMD;
 using gl::glBlendFuncSeparateEXT;
-using gl::glBlendFuncSeparateINGR;
-using gl::glBlendFuncSeparateIndexedAMD;
 using gl::glBlendFuncSeparateiARB;
-using gl::glBlendFunciARB;
+using gl::glBlendFuncSeparateIndexedAMD;
+using gl::glBlendFuncSeparateINGR;
 using gl::glBlendParameteriNV;
 using gl::glBlitFramebufferEXT;
 using gl::glBlitNamedFramebuffer;
@@ -112,6 +116,7 @@ using gl::glBufferAddressRangeNV;
 using gl::glBufferAttachMemoryNV;
 using gl::glBufferDataARB;
 using gl::glBufferPageCommitmentARB;
+using gl::glBufferPageCommitmentMemNV;
 using gl::glBufferParameteriAPPLE;
 using gl::glBufferStorage;
 using gl::glBufferStorageExternalEXT;
@@ -144,6 +149,7 @@ using gl::glClearTexSubImage;
 using gl::glClientActiveTextureARB;
 using gl::glClientActiveVertexStreamATI;
 using gl::glClientAttribDefaultEXT;
+using gl::glClientWaitSemaphoreui64NVX;
 using gl::glClipControl;
 using gl::glClipPlanefOES;
 using gl::glClipPlanexOES;
@@ -258,12 +264,12 @@ using gl::glCopyTextureSubImage2D;
 using gl::glCopyTextureSubImage2DEXT;
 using gl::glCopyTextureSubImage3D;
 using gl::glCopyTextureSubImage3DEXT;
+using gl::glCoverageModulationNV;
+using gl::glCoverageModulationTableNV;
 using gl::glCoverFillPathInstancedNV;
 using gl::glCoverFillPathNV;
 using gl::glCoverStrokePathInstancedNV;
 using gl::glCoverStrokePathNV;
-using gl::glCoverageModulationNV;
-using gl::glCoverageModulationTableNV;
 using gl::glCreateBuffers;
 using gl::glCreateCommandListsNV;
 using gl::glCreateFramebuffers;
@@ -271,11 +277,14 @@ using gl::glCreateMemoryObjectsEXT;
 using gl::glCreatePerfQueryINTEL;
 using gl::glCreateProgramObjectARB;
 using gl::glCreateProgramPipelines;
+using gl::glCreateProgressFenceNVX;
 using gl::glCreateQueries;
 using gl::glCreateRenderbuffers;
 using gl::glCreateSamplers;
+using gl::glCreateSemaphoresNV;
 using gl::glCreateShaderObjectARB;
 using gl::glCreateShaderProgramEXT;
+using gl::glCreateShaderProgramvEXT;
 using gl::glCreateStatesNV;
 using gl::glCreateSyncFromCLeventARB;
 using gl::glCreateTextures;
@@ -287,15 +296,18 @@ using gl::glCurrentPaletteMatrixARB;
 using gl::glDebugMessageCallback;
 using gl::glDebugMessageCallbackAMD;
 using gl::glDebugMessageCallbackARB;
+using gl::glDebugMessageCallbackKHR;
 using gl::glDebugMessageControl;
 using gl::glDebugMessageControlARB;
+using gl::glDebugMessageControlKHR;
 using gl::glDebugMessageEnableAMD;
 using gl::glDebugMessageInsert;
 using gl::glDebugMessageInsertAMD;
 using gl::glDebugMessageInsertARB;
-using gl::glDeformSGIX;
+using gl::glDebugMessageInsertKHR;
 using gl::glDeformationMap3dSGIX;
 using gl::glDeformationMap3fSGIX;
+using gl::glDeformSGIX;
 using gl::glDeleteAsyncMarkersSGIX;
 using gl::glDeleteBuffersARB;
 using gl::glDeleteCommandListsNV;
@@ -311,6 +323,7 @@ using gl::glDeleteOcclusionQueriesNV;
 using gl::glDeletePathsNV;
 using gl::glDeletePerfMonitorsAMD;
 using gl::glDeletePerfQueryINTEL;
+using gl::glDeleteProgramPipelinesEXT;
 using gl::glDeleteProgramsARB;
 using gl::glDeleteProgramsNV;
 using gl::glDeleteQueriesARB;
@@ -322,15 +335,17 @@ using gl::glDeleteTexturesEXT;
 using gl::glDeleteTransformFeedbacksNV;
 using gl::glDeleteVertexArraysAPPLE;
 using gl::glDeleteVertexShaderEXT;
-using gl::glDepthBoundsEXT;
 using gl::glDepthBoundsdNV;
+using gl::glDepthBoundsEXT;
+using gl::glDepthRangeArraydvNV;
 using gl::glDepthRangedNV;
 using gl::glDepthRangefOES;
+using gl::glDepthRangeIndexeddNV;
 using gl::glDepthRangexOES;
 using gl::glDetachObjectARB;
 using gl::glDetailTexFuncSGIS;
-using gl::glDisableClientStateIndexedEXT;
 using gl::glDisableClientStateiEXT;
+using gl::glDisableClientStateIndexedEXT;
 using gl::glDisableIndexedEXT;
 using gl::glDisableVariantClientStateEXT;
 using gl::glDisableVertexArrayAttrib;
@@ -368,15 +383,15 @@ using gl::glDrawTransformFeedbackInstanced;
 using gl::glDrawTransformFeedbackNV;
 using gl::glDrawTransformFeedbackStreamInstanced;
 using gl::glDrawVkImageNV;
-using gl::glEGLImageTargetTexStorageEXT;
-using gl::glEGLImageTargetTextureStorageEXT;
 using gl::glEdgeFlagFormatNV;
 using gl::glEdgeFlagPointerEXT;
 using gl::glEdgeFlagPointerListIBM;
+using gl::glEGLImageTargetTexStorageEXT;
+using gl::glEGLImageTargetTextureStorageEXT;
 using gl::glElementPointerAPPLE;
 using gl::glElementPointerATI;
-using gl::glEnableClientStateIndexedEXT;
 using gl::glEnableClientStateiEXT;
+using gl::glEnableClientStateIndexedEXT;
 using gl::glEnableIndexedEXT;
 using gl::glEnableVariantClientStateEXT;
 using gl::glEnableVertexArrayAttrib;
@@ -418,38 +433,37 @@ using gl::glFlushRasterSGIX;
 using gl::glFlushStaticDataIBM;
 using gl::glFlushVertexArrayRangeAPPLE;
 using gl::glFlushVertexArrayRangeNV;
-using gl::glFogCoordFormatNV;
-using gl::glFogCoordPointerEXT;
-using gl::glFogCoordPointerListIBM;
 using gl::glFogCoorddEXT;
 using gl::glFogCoorddvEXT;
 using gl::glFogCoordfEXT;
+using gl::glFogCoordFormatNV;
 using gl::glFogCoordfvEXT;
 using gl::glFogCoordhNV;
 using gl::glFogCoordhvNV;
+using gl::glFogCoordPointerEXT;
+using gl::glFogCoordPointerListIBM;
 using gl::glFogFuncSGIS;
 using gl::glFogxOES;
 using gl::glFogxvOES;
 using gl::glFragmentColorMaterialSGIX;
 using gl::glFragmentCoverageColorNV;
-using gl::glFragmentLightModelfSGIX;
-using gl::glFragmentLightModelfvSGIX;
-using gl::glFragmentLightModeliSGIX;
-using gl::glFragmentLightModelivSGIX;
 using gl::glFragmentLightfSGIX;
 using gl::glFragmentLightfvSGIX;
 using gl::glFragmentLightiSGIX;
 using gl::glFragmentLightivSGIX;
+using gl::glFragmentLightModelfSGIX;
+using gl::glFragmentLightModelfvSGIX;
+using gl::glFragmentLightModeliSGIX;
+using gl::glFragmentLightModelivSGIX;
 using gl::glFragmentMaterialfSGIX;
 using gl::glFragmentMaterialfvSGIX;
 using gl::glFragmentMaterialiSGIX;
 using gl::glFragmentMaterialivSGIX;
-using gl::glFrameTerminatorGREMEDY;
-using gl::glFrameZoomSGIX;
 using gl::glFramebufferDrawBufferEXT;
 using gl::glFramebufferDrawBuffersEXT;
 using gl::glFramebufferFetchBarrierEXT;
 using gl::glFramebufferParameteri;
+using gl::glFramebufferParameteriMESA;
 using gl::glFramebufferReadBufferEXT;
 using gl::glFramebufferRenderbufferEXT;
 using gl::glFramebufferSampleLocationsfvARB;
@@ -465,11 +479,17 @@ using gl::glFramebufferTextureFaceEXT;
 using gl::glFramebufferTextureLayerARB;
 using gl::glFramebufferTextureLayerEXT;
 using gl::glFramebufferTextureMultiviewOVR;
+using gl::glFrameTerminatorGREMEDY;
+using gl::glFrameZoomSGIX;
 using gl::glFreeObjectBufferATI;
 using gl::glFrustumfOES;
 using gl::glFrustumxOES;
 using gl::glGenAsyncMarkersSGIX;
 using gl::glGenBuffersARB;
+using gl::glGenerateMipmapEXT;
+using gl::glGenerateMultiTexMipmapEXT;
+using gl::glGenerateTextureMipmap;
+using gl::glGenerateTextureMipmapEXT;
 using gl::glGenFencesAPPLE;
 using gl::glGenFencesNV;
 using gl::glGenFragmentShadersATI;
@@ -478,6 +498,7 @@ using gl::glGenNamesAMD;
 using gl::glGenOcclusionQueriesNV;
 using gl::glGenPathsNV;
 using gl::glGenPerfMonitorsAMD;
+using gl::glGenProgramPipelinesEXT;
 using gl::glGenProgramsARB;
 using gl::glGenProgramsNV;
 using gl::glGenQueriesARB;
@@ -489,10 +510,6 @@ using gl::glGenTexturesEXT;
 using gl::glGenTransformFeedbacksNV;
 using gl::glGenVertexArraysAPPLE;
 using gl::glGenVertexShadersEXT;
-using gl::glGenerateMipmapEXT;
-using gl::glGenerateMultiTexMipmapEXT;
-using gl::glGenerateTextureMipmap;
-using gl::glGenerateTextureMipmapEXT;
 using gl::glGetActiveAtomicCounterBufferiv;
 using gl::glGetActiveAttribARB;
 using gl::glGetActiveUniformARB;
@@ -539,16 +556,17 @@ using gl::glGetCoverageModulationTableNV;
 using gl::glGetDebugMessageLog;
 using gl::glGetDebugMessageLogAMD;
 using gl::glGetDebugMessageLogARB;
+using gl::glGetDebugMessageLogKHR;
 using gl::glGetDetailTexFuncSGIS;
-using gl::glGetDoubleIndexedvEXT;
 using gl::glGetDoublei_vEXT;
+using gl::glGetDoubleIndexedvEXT;
 using gl::glGetFenceivNV;
 using gl::glGetFinalCombinerInputParameterfvNV;
 using gl::glGetFinalCombinerInputParameterivNV;
 using gl::glGetFirstPerfQueryIdINTEL;
 using gl::glGetFixedvOES;
-using gl::glGetFloatIndexedvEXT;
 using gl::glGetFloati_vEXT;
+using gl::glGetFloatIndexedvEXT;
 using gl::glGetFogFuncSGIS;
 using gl::glGetFragDataLocationEXT;
 using gl::glGetFragmentLightfvSGIX;
@@ -559,8 +577,10 @@ using gl::glGetFramebufferAttachmentParameterivEXT;
 using gl::glGetFramebufferParameterfvAMD;
 using gl::glGetFramebufferParameteriv;
 using gl::glGetFramebufferParameterivEXT;
+using gl::glGetFramebufferParameterivMESA;
 using gl::glGetGraphicsResetStatus;
 using gl::glGetGraphicsResetStatusARB;
+using gl::glGetGraphicsResetStatusKHR;
 using gl::glGetHandleARB;
 using gl::glGetHistogram;
 using gl::glGetHistogramEXT;
@@ -578,13 +598,14 @@ using gl::glGetInstrumentsSGIX;
 using gl::glGetIntegerIndexedvEXT;
 using gl::glGetIntegerui64i_vNV;
 using gl::glGetIntegerui64vNV;
-using gl::glGetInternalformatSampleivNV;
 using gl::glGetInternalformati64v;
 using gl::glGetInternalformativ;
+using gl::glGetInternalformatSampleivNV;
 using gl::glGetInvariantBooleanvEXT;
 using gl::glGetInvariantFloatvEXT;
 using gl::glGetInvariantIntegervEXT;
 using gl::glGetLightxOES;
+using gl::glGetLightxvOES;
 using gl::glGetListParameterfvSGIX;
 using gl::glGetListParameterivSGIX;
 using gl::glGetLocalConstantBooleanvEXT;
@@ -597,6 +618,7 @@ using gl::glGetMapParameterfvNV;
 using gl::glGetMapParameterivNV;
 using gl::glGetMapxvOES;
 using gl::glGetMaterialxOES;
+using gl::glGetMaterialxvOES;
 using gl::glGetMemoryObjectDetachedResourcesuivNV;
 using gl::glGetMemoryObjectParameterivEXT;
 using gl::glGetMinmax;
@@ -605,6 +627,7 @@ using gl::glGetMinmaxParameterfv;
 using gl::glGetMinmaxParameterfvEXT;
 using gl::glGetMinmaxParameteriv;
 using gl::glGetMinmaxParameterivEXT;
+using gl::glGetMultisamplefvNV;
 using gl::glGetMultiTexEnvfvEXT;
 using gl::glGetMultiTexEnvivEXT;
 using gl::glGetMultiTexGendvEXT;
@@ -613,11 +636,10 @@ using gl::glGetMultiTexGenivEXT;
 using gl::glGetMultiTexImageEXT;
 using gl::glGetMultiTexLevelParameterfvEXT;
 using gl::glGetMultiTexLevelParameterivEXT;
+using gl::glGetMultiTexParameterfvEXT;
 using gl::glGetMultiTexParameterIivEXT;
 using gl::glGetMultiTexParameterIuivEXT;
-using gl::glGetMultiTexParameterfvEXT;
 using gl::glGetMultiTexParameterivEXT;
-using gl::glGetMultisamplefvNV;
 using gl::glGetNamedBufferParameteri64v;
 using gl::glGetNamedBufferParameteriv;
 using gl::glGetNamedBufferParameterivEXT;
@@ -631,192 +653,23 @@ using gl::glGetNamedFramebufferAttachmentParameterivEXT;
 using gl::glGetNamedFramebufferParameterfvAMD;
 using gl::glGetNamedFramebufferParameteriv;
 using gl::glGetNamedFramebufferParameterivEXT;
-using gl::glGetNamedProgramLocalParameterIivEXT;
-using gl::glGetNamedProgramLocalParameterIuivEXT;
+using gl::glGetNamedProgramivEXT;
 using gl::glGetNamedProgramLocalParameterdvEXT;
 using gl::glGetNamedProgramLocalParameterfvEXT;
+using gl::glGetNamedProgramLocalParameterIivEXT;
+using gl::glGetNamedProgramLocalParameterIuivEXT;
 using gl::glGetNamedProgramStringEXT;
-using gl::glGetNamedProgramivEXT;
 using gl::glGetNamedRenderbufferParameteriv;
 using gl::glGetNamedRenderbufferParameterivEXT;
 using gl::glGetNamedStringARB;
 using gl::glGetNamedStringivARB;
-using gl::glGetNextPerfQueryIdINTEL;
-using gl::glGetObjectBufferfvATI;
-using gl::glGetObjectBufferivATI;
-using gl::glGetObjectLabel;
-using gl::glGetObjectLabelEXT;
-using gl::glGetObjectParameterfvARB;
-using gl::glGetObjectParameterivAPPLE;
-using gl::glGetObjectParameterivARB;
-using gl::glGetObjectPtrLabel;
-using gl::glGetOcclusionQueryivNV;
-using gl::glGetOcclusionQueryuivNV;
-using gl::glGetPathColorGenfvNV;
-using gl::glGetPathColorGenivNV;
-using gl::glGetPathCommandsNV;
-using gl::glGetPathCoordsNV;
-using gl::glGetPathDashArrayNV;
-using gl::glGetPathLengthNV;
-using gl::glGetPathMetricRangeNV;
-using gl::glGetPathMetricsNV;
-using gl::glGetPathParameterfvNV;
-using gl::glGetPathParameterivNV;
-using gl::glGetPathSpacingNV;
-using gl::glGetPathTexGenfvNV;
-using gl::glGetPathTexGenivNV;
-using gl::glGetPerfCounterInfoINTEL;
-using gl::glGetPerfMonitorCounterDataAMD;
-using gl::glGetPerfMonitorCounterInfoAMD;
-using gl::glGetPerfMonitorCounterStringAMD;
-using gl::glGetPerfMonitorCountersAMD;
-using gl::glGetPerfMonitorGroupStringAMD;
-using gl::glGetPerfMonitorGroupsAMD;
-using gl::glGetPerfQueryDataINTEL;
-using gl::glGetPerfQueryIdByNameINTEL;
-using gl::glGetPerfQueryInfoINTEL;
-using gl::glGetPixelMapxv;
-using gl::glGetPixelTexGenParameterfvSGIS;
-using gl::glGetPixelTexGenParameterivSGIS;
-using gl::glGetPixelTransformParameterfvEXT;
-using gl::glGetPixelTransformParameterivEXT;
-using gl::glGetPointerIndexedvEXT;
-using gl::glGetPointeri_vEXT;
-using gl::glGetPointervEXT;
-using gl::glGetProgramEnvParameterIivNV;
-using gl::glGetProgramEnvParameterIuivNV;
-using gl::glGetProgramEnvParameterdvARB;
-using gl::glGetProgramEnvParameterfvARB;
-using gl::glGetProgramInterfaceiv;
-using gl::glGetProgramLocalParameterIivNV;
-using gl::glGetProgramLocalParameterIuivNV;
-using gl::glGetProgramLocalParameterdvARB;
-using gl::glGetProgramLocalParameterfvARB;
-using gl::glGetProgramNamedParameterdvNV;
-using gl::glGetProgramNamedParameterfvNV;
-using gl::glGetProgramParameterdvNV;
-using gl::glGetProgramParameterfvNV;
-using gl::glGetProgramResourceIndex;
-using gl::glGetProgramResourceLocation;
-using gl::glGetProgramResourceLocationIndex;
-using gl::glGetProgramResourceName;
-using gl::glGetProgramResourcefvNV;
-using gl::glGetProgramResourceiv;
-using gl::glGetProgramStringARB;
-using gl::glGetProgramStringNV;
-using gl::glGetProgramSubroutineParameteruivNV;
-using gl::glGetProgramivARB;
-using gl::glGetProgramivNV;
-using gl::glGetQueryBufferObjecti64v;
-using gl::glGetQueryBufferObjectiv;
-using gl::glGetQueryBufferObjectui64v;
-using gl::glGetQueryBufferObjectuiv;
-using gl::glGetQueryObjecti64vEXT;
-using gl::glGetQueryObjectivARB;
-using gl::glGetQueryObjectui64vEXT;
-using gl::glGetQueryObjectuivARB;
-using gl::glGetQueryivARB;
-using gl::glGetRenderbufferParameterivEXT;
-using gl::glGetSemaphoreParameterui64vEXT;
-using gl::glGetSeparableFilter;
-using gl::glGetSeparableFilterEXT;
-using gl::glGetShaderSourceARB;
-using gl::glGetShadingRateImagePaletteNV;
-using gl::glGetShadingRateSampleLocationivNV;
-using gl::glGetSharpenTexFuncSGIS;
-using gl::glGetStageIndexNV;
-using gl::glGetTexBumpParameterfvATI;
-using gl::glGetTexBumpParameterivATI;
-using gl::glGetTexEnvxvOES;
-using gl::glGetTexFilterFuncSGIS;
-using gl::glGetTexGenxvOES;
-using gl::glGetTexLevelParameterxvOES;
-using gl::glGetTexParameterIivEXT;
-using gl::glGetTexParameterIuivEXT;
-using gl::glGetTexParameterPointervAPPLE;
-using gl::glGetTexParameterxvOES;
-using gl::glGetTextureHandleARB;
-using gl::glGetTextureHandleNV;
-using gl::glGetTextureImage;
-using gl::glGetTextureImageEXT;
-using gl::glGetTextureLevelParameterfv;
-using gl::glGetTextureLevelParameterfvEXT;
-using gl::glGetTextureLevelParameteriv;
-using gl::glGetTextureLevelParameterivEXT;
-using gl::glGetTextureParameterIiv;
-using gl::glGetTextureParameterIivEXT;
-using gl::glGetTextureParameterIuiv;
-using gl::glGetTextureParameterIuivEXT;
-using gl::glGetTextureParameterfv;
-using gl::glGetTextureParameterfvEXT;
-using gl::glGetTextureParameteriv;
-using gl::glGetTextureParameterivEXT;
-using gl::glGetTextureSamplerHandleARB;
-using gl::glGetTextureSamplerHandleNV;
-using gl::glGetTextureSubImage;
-using gl::glGetTrackMatrixivNV;
-using gl::glGetTransformFeedbackVaryingEXT;
-using gl::glGetTransformFeedbackVaryingNV;
-using gl::glGetTransformFeedbacki64_v;
-using gl::glGetTransformFeedbacki_v;
-using gl::glGetTransformFeedbackiv;
-using gl::glGetUniformBufferSizeEXT;
-using gl::glGetUniformLocationARB;
-using gl::glGetUniformOffsetEXT;
-using gl::glGetUniformfvARB;
-using gl::glGetUniformi64vARB;
-using gl::glGetUniformi64vNV;
-using gl::glGetUniformivARB;
-using gl::glGetUniformui64vARB;
-using gl::glGetUniformui64vNV;
-using gl::glGetUniformuivEXT;
-using gl::glGetUnsignedBytei_vEXT;
-using gl::glGetUnsignedBytevEXT;
-using gl::glGetVariantArrayObjectfvATI;
-using gl::glGetVariantArrayObjectivATI;
-using gl::glGetVariantBooleanvEXT;
-using gl::glGetVariantFloatvEXT;
-using gl::glGetVariantIntegervEXT;
-using gl::glGetVariantPointervEXT;
-using gl::glGetVaryingLocationNV;
-using gl::glGetVertexArrayIndexed64iv;
-using gl::glGetVertexArrayIndexediv;
-using gl::glGetVertexArrayIntegeri_vEXT;
-using gl::glGetVertexArrayIntegervEXT;
-using gl::glGetVertexArrayPointeri_vEXT;
-using gl::glGetVertexArrayPointervEXT;
-using gl::glGetVertexArrayiv;
-using gl::glGetVertexAttribArrayObjectfvATI;
-using gl::glGetVertexAttribArrayObjectivATI;
-using gl::glGetVertexAttribIivEXT;
-using gl::glGetVertexAttribIuivEXT;
-using gl::glGetVertexAttribLdvEXT;
-using gl::glGetVertexAttribLi64vNV;
-using gl::glGetVertexAttribLui64vARB;
-using gl::glGetVertexAttribLui64vNV;
-using gl::glGetVertexAttribPointervARB;
-using gl::glGetVertexAttribPointervNV;
-using gl::glGetVertexAttribdvARB;
-using gl::glGetVertexAttribdvNV;
-using gl::glGetVertexAttribfvARB;
-using gl::glGetVertexAttribfvNV;
-using gl::glGetVertexAttribivARB;
-using gl::glGetVertexAttribivNV;
-using gl::glGetVideoCaptureStreamdvNV;
-using gl::glGetVideoCaptureStreamfvNV;
-using gl::glGetVideoCaptureStreamivNV;
-using gl::glGetVideoCaptureivNV;
-using gl::glGetVideoi64vNV;
-using gl::glGetVideoivNV;
-using gl::glGetVideoui64vNV;
-using gl::glGetVideouivNV;
-using gl::glGetVkProcAddrNV;
 using gl::glGetnColorTable;
 using gl::glGetnColorTableARB;
 using gl::glGetnCompressedTexImage;
 using gl::glGetnCompressedTexImageARB;
 using gl::glGetnConvolutionFilter;
 using gl::glGetnConvolutionFilterARB;
+using gl::glGetNextPerfQueryIdINTEL;
 using gl::glGetnHistogram;
 using gl::glGetnHistogramARB;
 using gl::glGetnMapdv;
@@ -843,12 +696,190 @@ using gl::glGetnUniformdv;
 using gl::glGetnUniformdvARB;
 using gl::glGetnUniformfv;
 using gl::glGetnUniformfvARB;
+using gl::glGetnUniformfvKHR;
 using gl::glGetnUniformi64vARB;
 using gl::glGetnUniformiv;
 using gl::glGetnUniformivARB;
+using gl::glGetnUniformivKHR;
 using gl::glGetnUniformui64vARB;
 using gl::glGetnUniformuiv;
 using gl::glGetnUniformuivARB;
+using gl::glGetnUniformuivKHR;
+using gl::glGetObjectBufferfvATI;
+using gl::glGetObjectBufferivATI;
+using gl::glGetObjectLabel;
+using gl::glGetObjectLabelEXT;
+using gl::glGetObjectLabelKHR;
+using gl::glGetObjectParameterfvARB;
+using gl::glGetObjectParameterivAPPLE;
+using gl::glGetObjectParameterivARB;
+using gl::glGetObjectPtrLabel;
+using gl::glGetObjectPtrLabelKHR;
+using gl::glGetOcclusionQueryivNV;
+using gl::glGetOcclusionQueryuivNV;
+using gl::glGetPathColorGenfvNV;
+using gl::glGetPathColorGenivNV;
+using gl::glGetPathCommandsNV;
+using gl::glGetPathCoordsNV;
+using gl::glGetPathDashArrayNV;
+using gl::glGetPathLengthNV;
+using gl::glGetPathMetricRangeNV;
+using gl::glGetPathMetricsNV;
+using gl::glGetPathParameterfvNV;
+using gl::glGetPathParameterivNV;
+using gl::glGetPathSpacingNV;
+using gl::glGetPathTexGenfvNV;
+using gl::glGetPathTexGenivNV;
+using gl::glGetPerfCounterInfoINTEL;
+using gl::glGetPerfMonitorCounterDataAMD;
+using gl::glGetPerfMonitorCounterInfoAMD;
+using gl::glGetPerfMonitorCountersAMD;
+using gl::glGetPerfMonitorCounterStringAMD;
+using gl::glGetPerfMonitorGroupsAMD;
+using gl::glGetPerfMonitorGroupStringAMD;
+using gl::glGetPerfQueryDataINTEL;
+using gl::glGetPerfQueryIdByNameINTEL;
+using gl::glGetPerfQueryInfoINTEL;
+using gl::glGetPixelMapxv;
+using gl::glGetPixelTexGenParameterfvSGIS;
+using gl::glGetPixelTexGenParameterivSGIS;
+using gl::glGetPixelTransformParameterfvEXT;
+using gl::glGetPixelTransformParameterivEXT;
+using gl::glGetPointeri_vEXT;
+using gl::glGetPointerIndexedvEXT;
+using gl::glGetPointervEXT;
+using gl::glGetPointervKHR;
+using gl::glGetProgramEnvParameterdvARB;
+using gl::glGetProgramEnvParameterfvARB;
+using gl::glGetProgramEnvParameterIivNV;
+using gl::glGetProgramEnvParameterIuivNV;
+using gl::glGetProgramInterfaceiv;
+using gl::glGetProgramivARB;
+using gl::glGetProgramivNV;
+using gl::glGetProgramLocalParameterdvARB;
+using gl::glGetProgramLocalParameterfvARB;
+using gl::glGetProgramLocalParameterIivNV;
+using gl::glGetProgramLocalParameterIuivNV;
+using gl::glGetProgramNamedParameterdvNV;
+using gl::glGetProgramNamedParameterfvNV;
+using gl::glGetProgramParameterdvNV;
+using gl::glGetProgramParameterfvNV;
+using gl::glGetProgramPipelineInfoLogEXT;
+using gl::glGetProgramPipelineivEXT;
+using gl::glGetProgramResourcefvNV;
+using gl::glGetProgramResourceIndex;
+using gl::glGetProgramResourceiv;
+using gl::glGetProgramResourceLocation;
+using gl::glGetProgramResourceLocationIndex;
+using gl::glGetProgramResourceName;
+using gl::glGetProgramStringARB;
+using gl::glGetProgramStringNV;
+using gl::glGetProgramSubroutineParameteruivNV;
+using gl::glGetQueryBufferObjecti64v;
+using gl::glGetQueryBufferObjectiv;
+using gl::glGetQueryBufferObjectui64v;
+using gl::glGetQueryBufferObjectuiv;
+using gl::glGetQueryivARB;
+using gl::glGetQueryObjecti64vEXT;
+using gl::glGetQueryObjectivARB;
+using gl::glGetQueryObjectui64vEXT;
+using gl::glGetQueryObjectuivARB;
+using gl::glGetRenderbufferParameterivEXT;
+using gl::glGetSemaphoreParameterivNV;
+using gl::glGetSemaphoreParameterui64vEXT;
+using gl::glGetSeparableFilter;
+using gl::glGetSeparableFilterEXT;
+using gl::glGetShaderSourceARB;
+using gl::glGetShadingRateImagePaletteNV;
+using gl::glGetShadingRateSampleLocationivNV;
+using gl::glGetSharpenTexFuncSGIS;
+using gl::glGetStageIndexNV;
+using gl::glGetTexBumpParameterfvATI;
+using gl::glGetTexBumpParameterivATI;
+using gl::glGetTexEnvxvOES;
+using gl::glGetTexFilterFuncSGIS;
+using gl::glGetTexGenxvOES;
+using gl::glGetTexLevelParameterxvOES;
+using gl::glGetTexParameterIivEXT;
+using gl::glGetTexParameterIuivEXT;
+using gl::glGetTexParameterPointervAPPLE;
+using gl::glGetTexParameterxvOES;
+using gl::glGetTextureHandleARB;
+using gl::glGetTextureHandleNV;
+using gl::glGetTextureImage;
+using gl::glGetTextureImageEXT;
+using gl::glGetTextureLevelParameterfv;
+using gl::glGetTextureLevelParameterfvEXT;
+using gl::glGetTextureLevelParameteriv;
+using gl::glGetTextureLevelParameterivEXT;
+using gl::glGetTextureParameterfv;
+using gl::glGetTextureParameterfvEXT;
+using gl::glGetTextureParameterIiv;
+using gl::glGetTextureParameterIivEXT;
+using gl::glGetTextureParameterIuiv;
+using gl::glGetTextureParameterIuivEXT;
+using gl::glGetTextureParameteriv;
+using gl::glGetTextureParameterivEXT;
+using gl::glGetTextureSamplerHandleARB;
+using gl::glGetTextureSamplerHandleNV;
+using gl::glGetTextureSubImage;
+using gl::glGetTrackMatrixivNV;
+using gl::glGetTransformFeedbacki64_v;
+using gl::glGetTransformFeedbacki_v;
+using gl::glGetTransformFeedbackiv;
+using gl::glGetTransformFeedbackVaryingEXT;
+using gl::glGetTransformFeedbackVaryingNV;
+using gl::glGetUniformBufferSizeEXT;
+using gl::glGetUniformfvARB;
+using gl::glGetUniformi64vARB;
+using gl::glGetUniformi64vNV;
+using gl::glGetUniformivARB;
+using gl::glGetUniformLocationARB;
+using gl::glGetUniformOffsetEXT;
+using gl::glGetUniformui64vARB;
+using gl::glGetUniformui64vNV;
+using gl::glGetUniformuivEXT;
+using gl::glGetUnsignedBytei_vEXT;
+using gl::glGetUnsignedBytevEXT;
+using gl::glGetVariantArrayObjectfvATI;
+using gl::glGetVariantArrayObjectivATI;
+using gl::glGetVariantBooleanvEXT;
+using gl::glGetVariantFloatvEXT;
+using gl::glGetVariantIntegervEXT;
+using gl::glGetVariantPointervEXT;
+using gl::glGetVaryingLocationNV;
+using gl::glGetVertexArrayIndexed64iv;
+using gl::glGetVertexArrayIndexediv;
+using gl::glGetVertexArrayIntegeri_vEXT;
+using gl::glGetVertexArrayIntegervEXT;
+using gl::glGetVertexArrayiv;
+using gl::glGetVertexArrayPointeri_vEXT;
+using gl::glGetVertexArrayPointervEXT;
+using gl::glGetVertexAttribArrayObjectfvATI;
+using gl::glGetVertexAttribArrayObjectivATI;
+using gl::glGetVertexAttribdvARB;
+using gl::glGetVertexAttribdvNV;
+using gl::glGetVertexAttribfvARB;
+using gl::glGetVertexAttribfvNV;
+using gl::glGetVertexAttribIivEXT;
+using gl::glGetVertexAttribIuivEXT;
+using gl::glGetVertexAttribivARB;
+using gl::glGetVertexAttribivNV;
+using gl::glGetVertexAttribLdvEXT;
+using gl::glGetVertexAttribLi64vNV;
+using gl::glGetVertexAttribLui64vARB;
+using gl::glGetVertexAttribLui64vNV;
+using gl::glGetVertexAttribPointervARB;
+using gl::glGetVertexAttribPointervNV;
+using gl::glGetVideoCaptureivNV;
+using gl::glGetVideoCaptureStreamdvNV;
+using gl::glGetVideoCaptureStreamfvNV;
+using gl::glGetVideoCaptureStreamivNV;
+using gl::glGetVideoi64vNV;
+using gl::glGetVideoivNV;
+using gl::glGetVideoui64vNV;
+using gl::glGetVideouivNV;
+using gl::glGetVkProcAddrNV;
 using gl::glGlobalAlphaFactorbSUN;
 using gl::glGlobalAlphaFactordSUN;
 using gl::glGlobalAlphaFactorfSUN;
@@ -912,6 +943,7 @@ using gl::glIsPointInFillPathNV;
 using gl::glIsPointInStrokePathNV;
 using gl::glIsProgramARB;
 using gl::glIsProgramNV;
+using gl::glIsProgramPipelineEXT;
 using gl::glIsQueryARB;
 using gl::glIsRenderbufferEXT;
 using gl::glIsSemaphoreEXT;
@@ -923,10 +955,10 @@ using gl::glIsTransformFeedbackNV;
 using gl::glIsVariantEnabledEXT;
 using gl::glIsVertexArrayAPPLE;
 using gl::glIsVertexAttribEnabledAPPLE;
+using gl::glLabelObjectEXT;
 using gl::glLGPUCopyImageSubDataNVX;
 using gl::glLGPUInterlockNVX;
 using gl::glLGPUNamedBufferSubDataNVX;
-using gl::glLabelObjectEXT;
 using gl::glLightEnviSGIX;
 using gl::glLightModelxOES;
 using gl::glLightModelxvOES;
@@ -985,19 +1017,19 @@ using gl::glMatrixIndexuivARB;
 using gl::glMatrixIndexusvARB;
 using gl::glMatrixLoad3x2fNV;
 using gl::glMatrixLoad3x3fNV;
+using gl::glMatrixLoaddEXT;
+using gl::glMatrixLoadfEXT;
 using gl::glMatrixLoadIdentityEXT;
 using gl::glMatrixLoadTranspose3x3fNV;
 using gl::glMatrixLoadTransposedEXT;
 using gl::glMatrixLoadTransposefEXT;
-using gl::glMatrixLoaddEXT;
-using gl::glMatrixLoadfEXT;
 using gl::glMatrixMult3x2fNV;
 using gl::glMatrixMult3x3fNV;
+using gl::glMatrixMultdEXT;
+using gl::glMatrixMultfEXT;
 using gl::glMatrixMultTranspose3x3fNV;
 using gl::glMatrixMultTransposedEXT;
 using gl::glMatrixMultTransposefEXT;
-using gl::glMatrixMultdEXT;
-using gl::glMatrixMultfEXT;
 using gl::glMatrixOrthoEXT;
 using gl::glMatrixPopEXT;
 using gl::glMatrixPushEXT;
@@ -1013,13 +1045,23 @@ using gl::glMemoryBarrier;
 using gl::glMemoryBarrierByRegion;
 using gl::glMemoryBarrierEXT;
 using gl::glMemoryObjectParameterivEXT;
-using gl::glMinSampleShadingARB;
 using gl::glMinmax;
 using gl::glMinmaxEXT;
-using gl::glMultMatrixxOES;
-using gl::glMultTransposeMatrixdARB;
-using gl::glMultTransposeMatrixfARB;
-using gl::glMultTransposeMatrixxOES;
+using gl::glMinSampleShadingARB;
+using gl::glMulticastBarrierNV;
+using gl::glMulticastBlitFramebufferNV;
+using gl::glMulticastBufferSubDataNV;
+using gl::glMulticastCopyBufferSubDataNV;
+using gl::glMulticastCopyImageSubDataNV;
+using gl::glMulticastFramebufferSampleLocationsfvNV;
+using gl::glMulticastGetQueryObjecti64vNV;
+using gl::glMulticastGetQueryObjectivNV;
+using gl::glMulticastGetQueryObjectui64vNV;
+using gl::glMulticastGetQueryObjectuivNV;
+using gl::glMulticastScissorArrayvNVX;
+using gl::glMulticastViewportArrayvNVX;
+using gl::glMulticastViewportPositionWScaleNVX;
+using gl::glMulticastWaitSyncNV;
 using gl::glMultiDrawArraysEXT;
 using gl::glMultiDrawArraysIndirect;
 using gl::glMultiDrawArraysIndirectAMD;
@@ -1111,32 +1153,26 @@ using gl::glMultiTexGenivEXT;
 using gl::glMultiTexImage1DEXT;
 using gl::glMultiTexImage2DEXT;
 using gl::glMultiTexImage3DEXT;
-using gl::glMultiTexParameterIivEXT;
-using gl::glMultiTexParameterIuivEXT;
 using gl::glMultiTexParameterfEXT;
 using gl::glMultiTexParameterfvEXT;
 using gl::glMultiTexParameteriEXT;
+using gl::glMultiTexParameterIivEXT;
+using gl::glMultiTexParameterIuivEXT;
 using gl::glMultiTexParameterivEXT;
 using gl::glMultiTexRenderbufferEXT;
 using gl::glMultiTexSubImage1DEXT;
 using gl::glMultiTexSubImage2DEXT;
 using gl::glMultiTexSubImage3DEXT;
-using gl::glMulticastBarrierNV;
-using gl::glMulticastBlitFramebufferNV;
-using gl::glMulticastBufferSubDataNV;
-using gl::glMulticastCopyBufferSubDataNV;
-using gl::glMulticastCopyImageSubDataNV;
-using gl::glMulticastFramebufferSampleLocationsfvNV;
-using gl::glMulticastGetQueryObjecti64vNV;
-using gl::glMulticastGetQueryObjectivNV;
-using gl::glMulticastGetQueryObjectui64vNV;
-using gl::glMulticastGetQueryObjectuivNV;
-using gl::glMulticastWaitSyncNV;
+using gl::glMultMatrixxOES;
+using gl::glMultTransposeMatrixdARB;
+using gl::glMultTransposeMatrixfARB;
+using gl::glMultTransposeMatrixxOES;
 using gl::glNamedBufferAttachMemoryNV;
 using gl::glNamedBufferData;
 using gl::glNamedBufferDataEXT;
 using gl::glNamedBufferPageCommitmentARB;
 using gl::glNamedBufferPageCommitmentEXT;
+using gl::glNamedBufferPageCommitmentMemNV;
 using gl::glNamedBufferStorage;
 using gl::glNamedBufferStorageEXT;
 using gl::glNamedBufferStorageExternalEXT;
@@ -1203,13 +1239,13 @@ using gl::glNormalStream3ivATI;
 using gl::glNormalStream3sATI;
 using gl::glNormalStream3svATI;
 using gl::glObjectLabel;
+using gl::glObjectLabelKHR;
 using gl::glObjectPtrLabel;
+using gl::glObjectPtrLabelKHR;
 using gl::glObjectPurgeableAPPLE;
 using gl::glObjectUnpurgeableAPPLE;
 using gl::glOrthofOES;
 using gl::glOrthoxOES;
-using gl::glPNTrianglesfATI;
-using gl::glPNTrianglesiATI;
 using gl::glPassTexCoordATI;
 using gl::glPassThroughxOES;
 using gl::glPathColorGenNV;
@@ -1248,6 +1284,8 @@ using gl::glPixelTransformParameterfvEXT;
 using gl::glPixelTransformParameteriEXT;
 using gl::glPixelTransformParameterivEXT;
 using gl::glPixelZoomxOES;
+using gl::glPNTrianglesfATI;
+using gl::glPNTrianglesiATI;
 using gl::glPointAlongPathNV;
 using gl::glPointParameterfARB;
 using gl::glPointParameterfEXT;
@@ -1257,6 +1295,7 @@ using gl::glPointParameterfvEXT;
 using gl::glPointParameterfvSGIS;
 using gl::glPointParameteriNV;
 using gl::glPointParameterivNV;
+using gl::glPointParameterxOES;
 using gl::glPointParameterxvOES;
 using gl::glPointSizexOES;
 using gl::glPollAsyncSGIX;
@@ -1266,6 +1305,7 @@ using gl::glPolygonOffsetClampEXT;
 using gl::glPolygonOffsetEXT;
 using gl::glPolygonOffsetxOES;
 using gl::glPopDebugGroup;
+using gl::glPopDebugGroupKHR;
 using gl::glPopGroupMarkerEXT;
 using gl::glPresentFrameDualFillNV;
 using gl::glPresentFrameKeyedNV;
@@ -1274,9 +1314,9 @@ using gl::glPrimitiveRestartIndexNV;
 using gl::glPrimitiveRestartNV;
 using gl::glPrioritizeTexturesEXT;
 using gl::glPrioritizeTexturesxOES;
+using gl::glProgramBufferParametersfvNV;
 using gl::glProgramBufferParametersIivNV;
 using gl::glProgramBufferParametersIuivNV;
-using gl::glProgramBufferParametersfvNV;
 using gl::glProgramEnvParameter4dARB;
 using gl::glProgramEnvParameter4dvARB;
 using gl::glProgramEnvParameter4fARB;
@@ -1406,6 +1446,7 @@ using gl::glProgramVertexLimitNV;
 using gl::glProvokingVertexEXT;
 using gl::glPushClientAttribDefaultEXT;
 using gl::glPushDebugGroup;
+using gl::glPushDebugGroupKHR;
 using gl::glPushGroupMarkerEXT;
 using gl::glQueryMatrixxOES;
 using gl::glQueryObjectParameteruiAMD;
@@ -1421,15 +1462,16 @@ using gl::glRasterSamplesEXT;
 using gl::glReadInstrumentsSGIX;
 using gl::glReadnPixels;
 using gl::glReadnPixelsARB;
+using gl::glReadnPixelsKHR;
 using gl::glRectxOES;
 using gl::glRectxvOES;
 using gl::glReferencePlaneSGIX;
 using gl::glReleaseKeyedMutexWin32EXT;
-using gl::glRenderGpuMaskNV;
 using gl::glRenderbufferStorageEXT;
 using gl::glRenderbufferStorageMultisampleAdvancedAMD;
 using gl::glRenderbufferStorageMultisampleCoverageNV;
 using gl::glRenderbufferStorageMultisampleEXT;
+using gl::glRenderGpuMaskNV;
 using gl::glReplacementCodePointerSUN;
 using gl::glReplacementCodeubSUN;
 using gl::glReplacementCodeubvSUN;
@@ -1464,6 +1506,7 @@ using gl::glResolveDepthValuesNV;
 using gl::glResumeTransformFeedbackNV;
 using gl::glRotatexOES;
 using gl::glSampleCoverageARB;
+using gl::glSampleCoveragexOES;
 using gl::glSampleMapATI;
 using gl::glSampleMaskEXT;
 using gl::glSampleMaskIndexedNV;
@@ -1495,6 +1538,7 @@ using gl::glSecondaryColorFormatNV;
 using gl::glSecondaryColorPointerEXT;
 using gl::glSecondaryColorPointerListIBM;
 using gl::glSelectPerfMonitorCountersAMD;
+using gl::glSemaphoreParameterivNV;
 using gl::glSemaphoreParameterui64vEXT;
 using gl::glSeparableFilter2D;
 using gl::glSeparableFilter2DEXT;
@@ -1515,6 +1559,7 @@ using gl::glShadingRateSampleOrderCustomNV;
 using gl::glShadingRateSampleOrderNV;
 using gl::glSharpenTexFuncSGIS;
 using gl::glSignalSemaphoreEXT;
+using gl::glSignalSemaphoreui64NVX;
 using gl::glSignalVkFenceNV;
 using gl::glSignalVkSemaphoreNV;
 using gl::glSpecializeShader;
@@ -1618,15 +1663,19 @@ using gl::glTexImage3DEXT;
 using gl::glTexImage3DMultisampleCoverageNV;
 using gl::glTexImage4DSGIS;
 using gl::glTexPageCommitmentARB;
+using gl::glTexPageCommitmentMemNV;
 using gl::glTexParameterIivEXT;
 using gl::glTexParameterIuivEXT;
 using gl::glTexParameterxOES;
 using gl::glTexParameterxvOES;
 using gl::glTexRenderbufferNV;
 using gl::glTexStorage1D;
+using gl::glTexStorage1DEXT;
 using gl::glTexStorage2D;
+using gl::glTexStorage2DEXT;
 using gl::glTexStorage2DMultisample;
 using gl::glTexStorage3D;
+using gl::glTexStorage3DEXT;
 using gl::glTexStorage3DMultisample;
 using gl::glTexStorageMem1DEXT;
 using gl::glTexStorageMem2DEXT;
@@ -1657,16 +1706,17 @@ using gl::glTextureLightEXT;
 using gl::glTextureMaterialEXT;
 using gl::glTextureNormalEXT;
 using gl::glTexturePageCommitmentEXT;
-using gl::glTextureParameterIiv;
-using gl::glTextureParameterIivEXT;
-using gl::glTextureParameterIuiv;
-using gl::glTextureParameterIuivEXT;
+using gl::glTexturePageCommitmentMemNV;
 using gl::glTextureParameterf;
 using gl::glTextureParameterfEXT;
 using gl::glTextureParameterfv;
 using gl::glTextureParameterfvEXT;
 using gl::glTextureParameteri;
 using gl::glTextureParameteriEXT;
+using gl::glTextureParameterIiv;
+using gl::glTextureParameterIivEXT;
+using gl::glTextureParameterIuiv;
+using gl::glTextureParameterIuivEXT;
 using gl::glTextureParameteriv;
 using gl::glTextureParameterivEXT;
 using gl::glTextureRangeAPPLE;
@@ -1776,8 +1826,22 @@ using gl::glUnmapNamedBufferEXT;
 using gl::glUnmapObjectBufferATI;
 using gl::glUnmapTexture2DINTEL;
 using gl::glUpdateObjectBufferATI;
+using gl::glUploadGpuMaskNVX;
 using gl::glUseProgramObjectARB;
+using gl::glUseProgramStagesEXT;
 using gl::glUseShaderProgramEXT;
+using gl::glValidateProgramARB;
+using gl::glValidateProgramPipelineEXT;
+using gl::glVariantArrayObjectATI;
+using gl::glVariantbvEXT;
+using gl::glVariantdvEXT;
+using gl::glVariantfvEXT;
+using gl::glVariantivEXT;
+using gl::glVariantPointerEXT;
+using gl::glVariantsvEXT;
+using gl::glVariantubvEXT;
+using gl::glVariantuivEXT;
+using gl::glVariantusvEXT;
 using gl::glVDPAUFiniNV;
 using gl::glVDPAUGetSurfaceivNV;
 using gl::glVDPAUInitNV;
@@ -1789,17 +1853,6 @@ using gl::glVDPAURegisterVideoSurfaceWithPictureStructureNV;
 using gl::glVDPAUSurfaceAccessNV;
 using gl::glVDPAUUnmapSurfacesNV;
 using gl::glVDPAUUnregisterSurfaceNV;
-using gl::glValidateProgramARB;
-using gl::glVariantArrayObjectATI;
-using gl::glVariantPointerEXT;
-using gl::glVariantbvEXT;
-using gl::glVariantdvEXT;
-using gl::glVariantfvEXT;
-using gl::glVariantivEXT;
-using gl::glVariantsvEXT;
-using gl::glVariantubvEXT;
-using gl::glVariantuivEXT;
-using gl::glVariantusvEXT;
 using gl::glVertex2bOES;
 using gl::glVertex2bvOES;
 using gl::glVertex2hNV;
@@ -1822,8 +1875,8 @@ using gl::glVertexArrayAttribBinding;
 using gl::glVertexArrayAttribFormat;
 using gl::glVertexArrayAttribIFormat;
 using gl::glVertexArrayAttribLFormat;
-using gl::glVertexArrayBindVertexBufferEXT;
 using gl::glVertexArrayBindingDivisor;
+using gl::glVertexArrayBindVertexBufferEXT;
 using gl::glVertexArrayColorOffsetEXT;
 using gl::glVertexArrayEdgeFlagOffsetEXT;
 using gl::glVertexArrayElementBuffer;
@@ -1890,13 +1943,6 @@ using gl::glVertexAttrib3sARB;
 using gl::glVertexAttrib3sNV;
 using gl::glVertexAttrib3svARB;
 using gl::glVertexAttrib3svNV;
-using gl::glVertexAttrib4NbvARB;
-using gl::glVertexAttrib4NivARB;
-using gl::glVertexAttrib4NsvARB;
-using gl::glVertexAttrib4NubARB;
-using gl::glVertexAttrib4NubvARB;
-using gl::glVertexAttrib4NuivARB;
-using gl::glVertexAttrib4NusvARB;
 using gl::glVertexAttrib4bvARB;
 using gl::glVertexAttrib4dARB;
 using gl::glVertexAttrib4dNV;
@@ -1909,6 +1955,13 @@ using gl::glVertexAttrib4fvNV;
 using gl::glVertexAttrib4hNV;
 using gl::glVertexAttrib4hvNV;
 using gl::glVertexAttrib4ivARB;
+using gl::glVertexAttrib4NbvARB;
+using gl::glVertexAttrib4NivARB;
+using gl::glVertexAttrib4NsvARB;
+using gl::glVertexAttrib4NubARB;
+using gl::glVertexAttrib4NubvARB;
+using gl::glVertexAttrib4NuivARB;
+using gl::glVertexAttrib4NusvARB;
 using gl::glVertexAttrib4sARB;
 using gl::glVertexAttrib4sNV;
 using gl::glVertexAttrib4svARB;
@@ -2035,11 +2088,11 @@ using gl::glVertexStream4iATI;
 using gl::glVertexStream4ivATI;
 using gl::glVertexStream4sATI;
 using gl::glVertexStream4svATI;
-using gl::glVertexWeightPointerEXT;
 using gl::glVertexWeightfEXT;
 using gl::glVertexWeightfvEXT;
 using gl::glVertexWeighthNV;
 using gl::glVertexWeighthvNV;
+using gl::glVertexWeightPointerEXT;
 using gl::glVideoCaptureNV;
 using gl::glVideoCaptureStreamParameterdvNV;
 using gl::glVideoCaptureStreamParameterfvNV;
@@ -2047,13 +2100,14 @@ using gl::glVideoCaptureStreamParameterivNV;
 using gl::glViewportPositionWScaleNV;
 using gl::glViewportSwizzleNV;
 using gl::glWaitSemaphoreEXT;
+using gl::glWaitSemaphoreui64NVX;
 using gl::glWaitVkSemaphoreNV;
-using gl::glWeightPathsNV;
-using gl::glWeightPointerARB;
 using gl::glWeightbvARB;
 using gl::glWeightdvARB;
 using gl::glWeightfvARB;
 using gl::glWeightivARB;
+using gl::glWeightPathsNV;
+using gl::glWeightPointerARB;
 using gl::glWeightsvARB;
 using gl::glWeightubvARB;
 using gl::glWeightuivARB;
@@ -2101,5 +2155,4 @@ using gl::glWindowPos4svMESA;
 using gl::glWindowRectanglesEXT;
 using gl::glWriteMaskEXT;
 
-
-} // namespace gl41ext
+} // namespace gl41ext
\ No newline at end of file
