@@ -12,65 +12,41 @@ namespace gl43
 
 
 // import bitfields to namespace
-using gl::GL_NONE_BIT;
-using gl::GL_CLIENT_PIXEL_STORE_BIT;
-using gl::GL_CONTEXT_CORE_PROFILE_BIT;
-using gl::GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT;
-using gl::GL_CURRENT_BIT;
-using gl::GL_SYNC_FLUSH_COMMANDS_BIT;
-using gl::GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT;
-using gl::GL_VERTEX_SHADER_BIT;
-using gl::GL_CLIENT_VERTEX_ARRAY_BIT;
-using gl::GL_CONTEXT_COMPATIBILITY_PROFILE_BIT;
-using gl::GL_CONTEXT_FLAG_DEBUG_BIT;
-using gl::GL_ELEMENT_ARRAY_BARRIER_BIT;
-using gl::GL_FRAGMENT_SHADER_BIT;
-using gl::GL_POINT_BIT;
-using gl::GL_GEOMETRY_SHADER_BIT;
-using gl::GL_LINE_BIT;
-using gl::GL_UNIFORM_BARRIER_BIT;
-using gl::GL_POLYGON_BIT;
-using gl::GL_TESS_CONTROL_SHADER_BIT;
-using gl::GL_TEXTURE_FETCH_BARRIER_BIT;
-using gl::GL_POLYGON_STIPPLE_BIT;
-using gl::GL_TESS_EVALUATION_SHADER_BIT;
-using gl::GL_COMPUTE_SHADER_BIT;
-using gl::GL_PIXEL_MODE_BIT;
-using gl::GL_SHADER_IMAGE_ACCESS_BARRIER_BIT;
-using gl::GL_COMMAND_BARRIER_BIT;
-using gl::GL_LIGHTING_BIT;
-using gl::GL_FOG_BIT;
-using gl::GL_PIXEL_BUFFER_BARRIER_BIT;
-using gl::GL_DEPTH_BUFFER_BIT;
-using gl::GL_TEXTURE_UPDATE_BARRIER_BIT;
-using gl::GL_ACCUM_BUFFER_BIT;
-using gl::GL_BUFFER_UPDATE_BARRIER_BIT;
-using gl::GL_FRAMEBUFFER_BARRIER_BIT;
-using gl::GL_STENCIL_BUFFER_BIT;
-using gl::GL_TRANSFORM_FEEDBACK_BARRIER_BIT;
-using gl::GL_VIEWPORT_BIT;
-using gl::GL_ATOMIC_COUNTER_BARRIER_BIT;
-using gl::GL_TRANSFORM_BIT;
-using gl::GL_ENABLE_BIT;
-using gl::GL_SHADER_STORAGE_BARRIER_BIT;
-using gl::GL_COLOR_BUFFER_BIT;
-using gl::GL_HINT_BIT;
-using gl::GL_MAP_READ_BIT;
-using gl::GL_EVAL_BIT;
-using gl::GL_MAP_WRITE_BIT;
-using gl::GL_LIST_BIT;
-using gl::GL_MAP_INVALIDATE_RANGE_BIT;
-using gl::GL_TEXTURE_BIT;
-using gl::GL_MAP_INVALIDATE_BUFFER_BIT;
-using gl::GL_SCISSOR_BIT;
-using gl::GL_MAP_FLUSH_EXPLICIT_BIT;
-using gl::GL_MAP_UNSYNCHRONIZED_BIT;
-using gl::GL_MULTISAMPLE_BIT;
-using gl::GL_ALL_ATTRIB_BITS;
 using gl::GL_ALL_BARRIER_BITS;
 using gl::GL_ALL_SHADER_BITS;
-using gl::GL_CLIENT_ALL_ATTRIB_BITS;
+using gl::GL_ATOMIC_COUNTER_BARRIER_BIT;
+using gl::GL_BUFFER_UPDATE_BARRIER_BIT;
+using gl::GL_COLOR_BUFFER_BIT;
+using gl::GL_COMMAND_BARRIER_BIT;
+using gl::GL_COMPUTE_SHADER_BIT;
+using gl::GL_CONTEXT_COMPATIBILITY_PROFILE_BIT;
+using gl::GL_CONTEXT_CORE_PROFILE_BIT;
+using gl::GL_CONTEXT_FLAG_DEBUG_BIT;
+using gl::GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT;
+using gl::GL_DEPTH_BUFFER_BIT;
+using gl::GL_ELEMENT_ARRAY_BARRIER_BIT;
+using gl::GL_FRAGMENT_SHADER_BIT;
+using gl::GL_FRAMEBUFFER_BARRIER_BIT;
+using gl::GL_GEOMETRY_SHADER_BIT;
+using gl::GL_MAP_FLUSH_EXPLICIT_BIT;
+using gl::GL_MAP_INVALIDATE_BUFFER_BIT;
+using gl::GL_MAP_INVALIDATE_RANGE_BIT;
+using gl::GL_MAP_READ_BIT;
+using gl::GL_MAP_UNSYNCHRONIZED_BIT;
+using gl::GL_MAP_WRITE_BIT;
+using gl::GL_PIXEL_BUFFER_BARRIER_BIT;
+using gl::GL_SHADER_IMAGE_ACCESS_BARRIER_BIT;
+using gl::GL_SHADER_STORAGE_BARRIER_BIT;
+using gl::GL_STENCIL_BUFFER_BIT;
+using gl::GL_SYNC_FLUSH_COMMANDS_BIT;
+using gl::GL_TESS_CONTROL_SHADER_BIT;
+using gl::GL_TESS_EVALUATION_SHADER_BIT;
+using gl::GL_TEXTURE_FETCH_BARRIER_BIT;
+using gl::GL_TEXTURE_UPDATE_BARRIER_BIT;
+using gl::GL_TRANSFORM_FEEDBACK_BARRIER_BIT;
+using gl::GL_UNIFORM_BARRIER_BIT;
+using gl::GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT;
+using gl::GL_VERTEX_SHADER_BIT;
 
 
-
-} // namespace gl43
+} // namespace gl43
\ No newline at end of file
